(function () {
    /**
     * Function to skip ads and remove ad overlays.
     */
    function handleAds() {
        const video = document.querySelector("video");
        const adOverlay = document.querySelector(".ytp-ad-player-overlay");

        // Skip video ads
        if (video && adOverlay && video.duration) {
            console.log("Ad detected. Skipping...");
            video.currentTime = video.duration; // Skip to the end of the ad
            video.play(); // Ensure the video continues playing
        }

        // Remove overlay ads and other ad elements
        const adElements = document.querySelectorAll(
            ".ytp-ad-module, .ytp-ad-image-overlay, .video-ads, .ytp-ad-overlay-slot"
        );
        adElements.forEach((ad) => {
            console.log("Removing ad element:", ad);
            ad.remove();
        });

        // Hide elements that obstruct video
        const skipButton = document.querySelector(".ytp-ad-skip-button");
        if (skipButton) {
            console.log("Skipping skippable ad...");
            skipButton.click();
        }
    }

    /**
     * Function to observe DOM changes for detecting ad elements dynamically.
     */
    function startAdObserver() {
        const observer = new MutationObserver(() => handleAds());
        observer.observe(document.body, { childList: true, subtree: true });

        console.log("Ad-skipping script loaded and observer started.");
    }

    // Check if the script is running in YouTube's environment
    if (window.location.host.includes("youtube.com")) {
        console.log("YouTube detected. Starting ad blocker...");
        startAdObserver();
    } else {
        console.log("This script is designed for YouTube. Exiting...");
    }
})();
